| MOLE_data | R Documentation |
In Li et al's (2025) study, respondents completed one of the four different FC scales. The current dataset contains their actual responses to the MOLE blocks, as well as their group information.
MOLE_data
A data frame with 2173 rows (respondents, 4 groups) and 40 columns #'
Li, M., Zhang, B., Li, L., Sun, T., & Brown, A. (2025). Mixed-keying or desirability-matching in the construction of forced-choice measures? An empirical investigation and practical recommendations. Organizational Research Methods, 28(2), 296-329. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1177/10944281241229784")}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.