cal_block_energy: Fast Calculation of Item Block "Energy"

View source: R/cal_block_energy.R

cal_block_energyR Documentation

Fast Calculation of Item Block "Energy"

Description

Calculates the total "energy" of one or multiple paired item blocks. This function has been heavily optimized for speed, as it is called thousands of times during the Simulated Annealing optimization loop.

Usage

cal_block_energy(block, char_list, weights, fun_list)

Arguments

block

An n by k integer matrix of item indices.

char_list

A list of vectors, where each vector contains the full item pool data for one specific characteristic.

weights

A numeric vector of weights.

fun_list

A list of pre-matched R function objects (e.g., list(facfun, var)).

Value

A numeric value indicating the total energy for the given item blocks.


autoFC documentation built on July 14, 2026, 5:07 p.m.