View source: R/empirical_reliability.R
| empirical_reliability | R Documentation |
Calculates empirical reliability for IRT-based trait scores using the formula provided by Brown & Maydeu-Olivares (2018).
empirical_reliability(dataset, score_names, se_names = NULL)
dataset |
A data frame containing the trait estimates and standard errors. |
score_names |
Character vector. The names of the columns specifying trait scores. |
se_names |
Optional character vector. The names of the columns specifying trait
standard errors. If |
For trait scores estimated using item response theory (IRT) models, a single test-level reliability coefficient (like Cronbach's Alpha) is often inappropriate because the standard error of measurement varies across the latent continuum.
Empirical reliability provides a summary estimate of how reliable the trait scores are "as a whole" by comparing the variance of the estimated scores to the average error variance.
A named numeric vector containing the empirical reliability estimates for each trait.
Mengtong Li
Brown, A., & Maydeu-Olivares, A. (2018). Ordinal factor analysis of graded-preference questionnaire data. Structural Equation Modeling, 25(4), 516-529. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1080/10705511.2017.1392247")}
# Create fake scores and standard errors
fake_scores <- data.frame(
Trait1 = rnorm(100), Trait1_SE = runif(100, 0.1, 0.3),
Trait2 = rnorm(100), Trait2_SE = runif(100, 0.2, 0.4)
)
# Auto-detects the "_SE" columns
empirical_reliability(fake_scores, score_names = c("Trait1", "Trait2"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.