predict_tirt_stan: Predict Trait Scores for New Data using a Fitted Stan Model

View source: R/predict_tirt_stan.R

predict_tirt_stanR Documentation

Predict Trait Scores for New Data using a Fitted Stan Model

Description

Extracts posterior means of item parameters from a fitted Stan TIRT model and uses analytical BFGS optimization to instantly score new respondents.

Usage

predict_tirt_stan(fit, stan_data, new_pairwise_data)

Arguments

fit

A fitted model object from either cmdstanr or rstan.

stan_data

The original data list passed to Stan (used to map the test design).

new_pairwise_data

A dataframe of pairwise binary responses for the NEW respondents.

Value

A data frame containing MAP trait scores and Standard Errors.


autoFC documentation built on July 14, 2026, 5:07 p.m.