prepare_tirt_stan_data: Prepare pairwise list data for Stan

View source: R/prepare_tirt_stan_data.R

prepare_tirt_stan_dataR Documentation

Prepare pairwise list data for Stan

Description

Prepare pairwise list data for Stan

Usage

prepare_tirt_stan_data(
  pairwise_data,
  n_blocks,
  block_size,
  key_matrix,
  trait_col,
  key_col,
  apply_heister = FALSE
)

Arguments

pairwise_data

A data frame of binary pairwise outcomes (output of convert_ranks_to_pairwise or convert_mole_to_pairwise).

n_blocks

Integer. Number of blocks in the questionnaire.

block_size

Integer. Number of items per block.

key_matrix

A data.frame indicating item trait and item sign.

trait_col

Character string. The name of the column in key_matrix indicating the trait measured by the item.

key_col

Character string. The name of the column in key_matrix indicating the keying direction of the item (e.g., positive/negative).

apply_heister

Experimental. Logical. Should the optimization techinques proposed by Heister et al., (2025) be applied? Default is FALSE.


autoFC documentation built on July 14, 2026, 5:07 p.m.