score_cfc_lavaan: Full-Information Closed-Form Trait Scoring for Compositional...

View source: R/score_cfc_lavaan.R

score_cfc_lavaanR Documentation

Full-Information Closed-Form Trait Scoring for Compositional FC Models

Description

Calculates exact, full-information MAP trait scores and Standard Errors for a fitted compositional forced-choice model, preserving all within-block local dependencies.

Usage

score_cfc_lavaan(fit, data, trait_names = NULL)

Arguments

fit

A fitted lavaan object from a compositional model, generated from cfa() function with the syntax built from generate_cfc_lavaan_syntax().

data

The log-ratio dataset used to fit the model.

trait_names

Optional character vector of the traits to score.

Value

A data frame containing the exact trait scores, followed by all standard errors (SE) of the traits.


autoFC documentation built on July 14, 2026, 5:07 p.m.