View source: R/generate_tirt_stan_syntax.R
| generate_tirt_stan_syntax | R Documentation |
Automatically reduces logical dependencies for full rank data (Heister et al. 2025), handles missing/MOLE data natively, and generates Stan syntax capable of within-chain parallelization (reduce_sum).
generate_tirt_stan_syntax(
pairwise_data,
n_blocks,
block_size,
n_traits,
key_matrix,
trait_col,
key_col,
apply_heister = TRUE
)
pairwise_data |
Dataframe of binary outcomes. |
n_blocks |
Integer. Number of blocks. |
block_size |
Integer. Number of items per block. |
n_traits |
Integer. Number of traits. |
key_matrix |
A data.frame indicating item trait and item sign. |
trait_col |
Character string. The name of the column in |
key_col |
Character string. The name of the column in |
apply_heister |
Logical. Apply logical dependency reduction? Defaults to TRUE. |
A list containing syntax (Stan code) and data (List for rstan).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.