| plot_scores | R Documentation |
This function provides a simple, enhanced diagnostic plot examining the performance of the forced-choice scale based on simulated or known true scores.
plot_scores(x_scores, y_scores, type = c("simple", "abs.diff"), ...)
x_scores |
Numeric vector. Scores to be plotted on the x-axis (typically True Scores). |
y_scores |
Numeric vector. Scores to be plotted on the y-axis (typically Estimated Scores). |
type |
Character. Which type of plot to display? Options are |
... |
Additional graphical parameters passed to |
This function extends base R plot() by automatically adding
standard diagnostic reference lines (a 1:1 identity line for "simple", and a
0-error baseline for "abs.diff") to aid visual inspection of bias.
A base R scatter plot.
true <- rnorm(100)
est <- true + rnorm(100, 0, 0.3)
plot_scores(true, est, type = "simple", main = "Recovery")
plot_scores(true, est, type = "abs.diff", main = "Error Magnitude")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.