View source: R/predict_tirt_stan.R
| predict_tirt_stan | R Documentation |
Extracts posterior means of item parameters from a fitted Stan TIRT model and uses analytical BFGS optimization to instantly score new respondents.
predict_tirt_stan(fit, stan_data, new_pairwise_data)
fit |
A fitted model object from either cmdstanr or rstan. |
stan_data |
The original data list passed to Stan (used to map the test design). |
new_pairwise_data |
A dataframe of pairwise binary responses for the NEW respondents. |
A data frame containing MAP trait scores and Standard Errors.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.