View source: R/score_cfc_lavaan.R
| score_cfc_lavaan | R Documentation |
Calculates exact, full-information MAP trait scores and Standard Errors for a fitted compositional forced-choice model, preserving all within-block local dependencies.
score_cfc_lavaan(fit, data, trait_names = NULL)
fit |
A fitted lavaan object from a compositional model, generated from |
data |
The log-ratio dataset used to fit the model. |
trait_names |
Optional character vector of the traits to score. |
A data frame containing the exact trait scores, followed by all standard errors (SE) of the traits.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.