View source: R/score_tirt_ipsative.R
| score_tirt_ipsative | R Documentation |
Calculates traditional ipsative sum scores from pairwise binary outcomes. Natively handles both full rankings and partial rankings (MOLE format) via pro-rated scaling, and automatically reverses scores for negatively-keyed items.
score_tirt_ipsative(
pairwise_data,
n_blocks,
block_size,
key_matrix,
trait_col,
key_col
)
pairwise_data |
A data frame of binary pairwise outcomes (output of
|
n_blocks |
Integer. Number of blocks in the questionnaire. |
block_size |
Integer. Number of items per block. |
key_matrix |
A data.frame indicating item trait and item sign. |
trait_col |
Character string. The name of the column in |
key_col |
Character string. The name of the column in |
A data frame of classical ipsative scores for each unique trait, with rows representing respondents.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.