View source: R/score_tirt_lavaan.R
| score_tirt_lavaan | R Documentation |
Calculates MAP trait scores and Standard Errors for a fitted lavaan model. Automatically detects whether the model uses the First-Order (TIRT) or Second-Order (TFM) parameterization.
score_tirt_lavaan(fit, data, trait_names = NULL, floor_value = 1e-04)
fit |
A fitted lavaan object. |
data |
The pairwise binary dataset used to fit the model. |
trait_names |
Character vector of the traits to score (e.g., c("Trait1", "Trait2")). Can be left NULL and detected by the function. |
floor_value |
Numeric. If negative residual variances for observed variables are provided, replace those negative residual variances with this floor value. |
A data frame containing Trait scores and their Standard Errors (SE).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.