View source: R/score_tirt_mplus.R
| score_tirt_mplus | R Documentation |
Extracts the estimated parameters from an Mplus .out file and uses a fast analytical gradient in R to instantly calculate MAP trait scores and Standard Errors. Works seamlessly for both First-Order (TIRT) and Second-Order (TFM) models.
score_tirt_mplus(inp_file, data, trait_names = NULL, run_model = TRUE)
inp_file |
Character. Path to the Mplus .inp (or .out) file. |
data |
The pairwise binary dataset used to fit the model. |
trait_names |
Optional character vector. The original names of the traits to use as column names in the final output. If NULL, uses the Mplus generated names. |
run_model |
Logical. If TRUE, runs Mplus before scoring. If FALSE, assumes the .out file already exists. Defaults to TRUE. |
A data frame containing Trait scores and their Standard Errors (SE).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.