View source: R/simulate_fc_data.R
| simulate_fc_data | R Documentation |
Simulates observed forced-choice responses (either complete rankings,
Most/Least partial rankings, or binary pairwise comparisons) from a matrix of
continuous latent utilities and a specified block design.
This is used in conjunction with get_simulation_matrices(), taking
use of the utility values it produces.
simulate_fc_data(utility_data, blocks, format = c("RANK", "MOLE", "PAIRWISE"))
utility_data |
A data frame or matrix of simulated latent utilities (e.g., the
|
blocks |
A matrix of block designs where each row represents a block of
item IDs (e.g., output of |
format |
Character. The desired output format: |
A data frame of the simulated observed responses.
For "RANK", columns represent the assigned rank of each item in the block
(e.g., "b1_i1_rank", "b1_i2_rank").
For "MOLE", columns indicate which item slot in the block was selected as
most/least (e.g., "b1_most", "b1_least" with values from 1 to block_size).
For "PAIRWISE", columns correspond to pair combinations (e.g., "i1i2").
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.